@@ -1,5 +1,4 @@
 # -*- coding: utf-8 -*-
-
 """
 Copyright (C) 2009-2016 Wolfgang Rohdewald <wolfgang@rohdewald.de>
 
@@ -8,23 +7,36 @@ SPDX-License-Identifier: GPL-2.0
 """
 
 import weakref
+from typing import Optional, TYPE_CHECKING, Dict, Any, Union, List, Tuple
 
-from common import Debug, StrMixin, Internal
+from common import ReprMixin, Internal
 from message import Message
 from wind import Wind
-from tile import Tile, TileList
-from meld import Meld, MeldList
+from tile import Tile, TileTuple, Meld, MeldList
+
+if TYPE_CHECKING:
+    from tilesource import TileSource
+    from player import PlayingPlayer
 
 
-class Move(StrMixin):
-
+class Move(ReprMixin):  # pylint: disable=too-many-instance-attributes
     """used for decoded move information from the game server"""
 
-    def __init__(self, player, command, kwargs):
+    def __init__(self, player:Optional['PlayingPlayer'],
+        command:Union[Message, str], kwargs:Dict[Any,Any]) ->None:
+
+        # pylint: disable=too-many-statements
+
+        self.message:Message
         if isinstance(command, Message):
             self.message = command
         else:
+            assert isinstance(command, str) # for mypy
             self.message = Message.defined[command]
+        self.tile:Tile
+        self.lastTile:Tile
+        self.withDiscardTile:Tile
+        self.tiles:TileTuple
         self.table = None
         self.notifying = False
         self._player = weakref.ref(player) if player else None
@@ -32,16 +44,30 @@ class Move(StrMixin):
         self.kwargs = kwargs.copy()
         del self.kwargs['token']
         self.score = None
-        self.lastMeld = None
+        self.lastMeld:Meld
+        self.meld:Meld
+        self.melds:MeldList
+        self.exposedMeld:Meld
+        self.source:'TileSource'
+        self.md5sum:str
+        self.wantedGame:str
+        self.show:bool
+        self.shouldSave:bool
+        self.playerNames:List[Tuple[Wind, str]]
+        self.deadEnd:bool
+        self.rotateWinds:bool
+        self.divideAt:int
+        self.tableid:int
+        self.gameid:int
         for key, value in kwargs.items():
-            assert not isinstance(value, bytes), 'value is bytes:{}'.format(repr(value))
+            assert not isinstance(value, bytes), f'value is bytes:{repr(value)}'
             if value is None:
                 self.__setattr__(key, None)
             else:
                 if key.lower().endswith('tile'):
                     self.__setattr__(key, Tile(value))
                 elif key.lower().endswith('tiles'):
-                    self.__setattr__(key, TileList(value))
+                    self.__setattr__(key, TileTuple(value))
                 elif key.lower().endswith('meld'):
                     self.__setattr__(key, Meld(value))
                 elif key.lower().endswith('melds'):
@@ -55,46 +81,18 @@ class Move(StrMixin):
                     self.__setattr__(key, value)
 
     @staticmethod
-    def __convertWinds(tuples):
+    def __convertWinds(tuples:List[Tuple[str, str]]) ->List[Tuple[Wind, str]]:
         """convert wind strings to Wind objects"""
-        result = list()
+        result = []
         for wind, name in tuples:
-            result.append(tuple([Wind(wind), name]))
+            _  = Wind(wind), name
+            result.append(_)
         return result
 
     @property
-    def player(self):
+    def player(self) ->Optional['PlayingPlayer']:
         """hide weakref"""
         return self._player() if self._player else None
 
-    @staticmethod
-    def prettyKwargs(kwargs):
-        """this is also used by the server, but the server does not use class Move"""
-        result = ''
-        for key in sorted(kwargs.keys()):
-            value = kwargs[key]
-            if key == 'token':
-                continue
-            if isinstance(value, (list, tuple)) and isinstance(value[0], (list, tuple)):
-                oldValue = value
-                tuples = []
-                for oldTuple in oldValue:
-                    tuples.append(''.join(str(x) for x in oldTuple))
-                value = ','.join(tuples)
-            if Debug.neutral and key == 'gameid':
-                result += ' gameid:GAMEID'
-            elif isinstance(value, bool) and value:
-                result += ' %s' % key
-            elif isinstance(value, bool):
-                pass
-            elif isinstance(value, bytes):
-                result += ' %s:%s' % (key, value.decode())
-            else:
-                result += ' %s:%s' % (key, value)
-        for old, new in (("('", "("), ("')", ")"), (" '", ""),
-                         ("',", ","), ("[(", "("), ("])", ")")):
-            result = result.replace(old, new)
-        return result
-
-    def __str__(self):
-        return '%s %s%s' % (self.player, self.message, Move.prettyKwargs(self.kwargs))
+    def __str__(self) ->str:
+        return f'{self.player!r} {self.message!r} {self.kwargs!r}'
